@@ -170,7 +170,7 @@ class Document(object):
             self.step += 1
             
             if not self.controller.handlers.has_key(f):
-                print self.controller.handlers.keys()
+                print sorted(self.controller.handlers.keys())
                 raise Exception("""You requested filter alias '%s'
                                 but this is not available.""" % f)
             HandlerClass = self.controller.handlers[f]
